==> hrthy.core-1.0.54-py3-none-any.whl: hrthy_core/security/constants.py <==
from hrthy_core.security.scopes import SCOPE_COMPANY_LIST, SCOPE_COMPANY_CREATE, SCOPE_COMPANY_UPDATE, \
    SCOPE_COMPANY_DELETE, SCOPE_COMPANY_RESTORE, SCOPE_USER_LIST, SCOPE_USER_CREATE, SCOPE_USER_UPDATE, \
    SCOPE_USER_DELETE, SCOPE_COMPANY_MY_UPDATE, SCOPE_USER_MY_LIST, \
    SCOPE_USER_MY_CREATE, SCOPE_USER_MY_UPDATE, SCOPE_USER_MY_DELETE, SCOPE_ROLE_LIST, SCOPE_ROLE_CREATE, \
    SCOPE_ROLE_UPDATE, SCOPE_ROLE_DELETE, SCOPE_ROLE_MY_LIST, SCOPE_COMPANY_MYSELF_GET, SCOPE_USER_MYSELF_GET, \
    SCOPE_CANDIDATE_MYSELF_GET, SCOPE_CANDIDATE_LIST, SCOPE_CANDIDATE_CREATE, SCOPE_USER_MYSELF_UPDATE, \
    SCOPE_CANDIDATE_UPDATE, SCOPE_CANDIDATE_DELETE, SCOPE_CANDIDATE_MYSELF_UPDATE, SCOPE_CANDIDATE_MY_LIST, \
    SCOPE_CANDIDATE_MY_CREATE, SCOPE_CANDIDATE_MY_UPDATE, SCOPE_CANDIDATE_MY_DELETE, SCOPE_PIPELINE_LIST, \
    SCOPE_PIPELINE_CREATE, SCOPE_PIPELINE_UPDATE, SCOPE_PIPELINE_DELETE, SCOPE_PIPELINE_MY_LIST, \
    SCOPE_PIPELINE_MY_CREATE, SCOPE_PIPELINE_MY_UPDATE, SCOPE_PIPELINE_MY_DELETE, SCOPE_PIPELINE_MYSELF_GET, \
    SCOPE_PIPELINE_CANDIDATE_ASSIGN, SCOPE_PIPELINE_CANDIDATE_UNASSIGN, SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN, \
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN

DEFAULT_SUPER_ADMIN_SCOPES = [
    SCOPE_COMPANY_LIST,
    SCOPE_COMPANY_CREATE,
    SCOPE_COMPANY_UPDATE,
    SCOPE_COMPANY_DELETE,
    SCOPE_COMPANY_RESTORE,
    SCOPE_USER_LIST,
    SCOPE_USER_CREATE,
    SCOPE_USER_UPDATE,
    SCOPE_USER_DELETE,
    SCOPE_ROLE_LIST,
    SCOPE_ROLE_CREATE,
    SCOPE_ROLE_UPDATE,
    SCOPE_ROLE_DELETE,
    SCOPE_CANDIDATE_LIST,
    SCOPE_CANDIDATE_CREATE,
    SCOPE_CANDIDATE_UPDATE,
    SCOPE_CANDIDATE_DELETE,
    SCOPE_PIPELINE_LIST,
    SCOPE_PIPELINE_CREATE,
    SCOPE_PIPELINE_UPDATE,
    SCOPE_PIPELINE_DELETE,
    SCOPE_PIPELINE_CANDIDATE_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_UNASSIGN
]

DEFAULT_ADMIN_SCOPES = [
    SCOPE_COMPANY_MYSELF_GET,
    SCOPE_COMPANY_MY_UPDATE,
    SCOPE_USER_MY_LIST,
    SCOPE_USER_MY_CREATE,
    SCOPE_USER_MY_UPDATE,
    SCOPE_USER_MY_DELETE,
    SCOPE_ROLE_MY_LIST,
    SCOPE_USER_MY_LIST,
    SCOPE_USER_MY_CREATE,
    SCOPE_USER_MY_UPDATE,
    SCOPE_USER_MY_DELETE,
    SCOPE_CANDIDATE_MY_LIST,
    SCOPE_CANDIDATE_MY_CREATE,
    SCOPE_CANDIDATE_MY_UPDATE,
    SCOPE_CANDIDATE_MY_DELETE,
    SCOPE_PIPELINE_MY_LIST,
    SCOPE_PIPELINE_MY_CREATE,
    SCOPE_PIPELINE_MY_UPDATE,
    SCOPE_PIPELINE_MY_DELETE,
    SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN
]

DEFAULT_USER_SCOPES = [
    SCOPE_COMPANY_MYSELF_GET,
    SCOPE_USER_MYSELF_GET,
    SCOPE_USER_MYSELF_UPDATE,
    SCOPE_CANDIDATE_MY_LIST,
    SCOPE_CANDIDATE_MY_CREATE,
    SCOPE_CANDIDATE_MY_UPDATE,
    SCOPE_PIPELINE_MY_LIST,
    SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN
]

DEFAULT_CANDIDATE_SCOPES = [
    SCOPE_CANDIDATE_MYSELF_GET,
    SCOPE_CANDIDATE_MYSELF_UPDATE,
    SCOPE_PIPELINE_MYSELF_GET
]

==> hrthy.core-1.0.65-py3-none-any.whl: hrthy_core/security/constants.py <==
from hrthy_core.security.scopes import SCOPE_COMPANY_LIST, SCOPE_COMPANY_CREATE, SCOPE_COMPANY_UPDATE, \
    SCOPE_COMPANY_DELETE, SCOPE_COMPANY_RESTORE, SCOPE_USER_LIST, SCOPE_USER_CREATE, SCOPE_USER_UPDATE, \
    SCOPE_USER_DELETE, SCOPE_COMPANY_MY_UPDATE, SCOPE_USER_MY_LIST, \
    SCOPE_USER_MY_CREATE, SCOPE_USER_MY_UPDATE, SCOPE_USER_MY_DELETE, SCOPE_ROLE_LIST, SCOPE_ROLE_CREATE, \
    SCOPE_ROLE_UPDATE, SCOPE_ROLE_DELETE, SCOPE_ROLE_MY_LIST, SCOPE_COMPANY_MYSELF_GET, SCOPE_USER_MYSELF_GET, \
    SCOPE_CANDIDATE_MYSELF_GET, SCOPE_CANDIDATE_LIST, SCOPE_CANDIDATE_CREATE, SCOPE_USER_MYSELF_UPDATE, \
    SCOPE_CANDIDATE_UPDATE, SCOPE_CANDIDATE_DELETE, SCOPE_CANDIDATE_MYSELF_UPDATE, SCOPE_CANDIDATE_MY_LIST, \
    SCOPE_CANDIDATE_MY_CREATE, SCOPE_CANDIDATE_MY_UPDATE, SCOPE_CANDIDATE_MY_DELETE, SCOPE_PIPELINE_LIST, \
    SCOPE_PIPELINE_CREATE, SCOPE_PIPELINE_UPDATE, SCOPE_PIPELINE_DELETE, SCOPE_PIPELINE_MY_LIST, \
    SCOPE_PIPELINE_MY_CREATE, SCOPE_PIPELINE_MY_UPDATE, SCOPE_PIPELINE_MY_DELETE, SCOPE_PIPELINE_MYSELF_GET, \
    SCOPE_PIPELINE_CANDIDATE_ASSIGN, SCOPE_PIPELINE_CANDIDATE_UNASSIGN, SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN, \
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN, SCOPE_ROLE_MY_ASSIGN_GLOBAL, SCOPE_ROLE_MYSELF_GET

DEFAULT_SUPER_ADMIN_SCOPES = [
    SCOPE_ROLE_MY_ASSIGN_GLOBAL,
    SCOPE_COMPANY_LIST,
    SCOPE_COMPANY_CREATE,
    SCOPE_COMPANY_UPDATE,
    SCOPE_COMPANY_DELETE,
    SCOPE_COMPANY_RESTORE,
    SCOPE_USER_LIST,
    SCOPE_USER_CREATE,
    SCOPE_USER_UPDATE,
    SCOPE_USER_DELETE,
    SCOPE_ROLE_LIST,
    SCOPE_ROLE_CREATE,
    SCOPE_ROLE_UPDATE,
    SCOPE_ROLE_DELETE,
    SCOPE_CANDIDATE_LIST,
    SCOPE_CANDIDATE_CREATE,
    SCOPE_CANDIDATE_UPDATE,
    SCOPE_CANDIDATE_DELETE,
    SCOPE_PIPELINE_LIST,
    SCOPE_PIPELINE_CREATE,
    SCOPE_PIPELINE_UPDATE,
    SCOPE_PIPELINE_DELETE,
    SCOPE_PIPELINE_CANDIDATE_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_UNASSIGN,
    SCOPE_COMPANY_MYSELF_GET,
    SCOPE_COMPANY_MY_UPDATE,
    SCOPE_USER_MY_LIST,
    SCOPE_USER_MY_CREATE,
    SCOPE_USER_MY_UPDATE,
    SCOPE_USER_MY_DELETE,
    SCOPE_ROLE_MY_LIST,
    SCOPE_CANDIDATE_MY_LIST,
    SCOPE_CANDIDATE_MY_CREATE,
    SCOPE_CANDIDATE_MY_UPDATE,
    SCOPE_CANDIDATE_MY_DELETE,
    SCOPE_PIPELINE_MY_LIST,
    SCOPE_PIPELINE_MY_CREATE,
    SCOPE_PIPELINE_MY_UPDATE,
    SCOPE_PIPELINE_MY_DELETE,
    SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN,
    SCOPE_USER_MYSELF_GET,
    SCOPE_USER_MYSELF_UPDATE
]

DEFAULT_ADMIN_SCOPES = [
    SCOPE_COMPANY_MYSELF_GET,
    SCOPE_COMPANY_MY_UPDATE,
    SCOPE_USER_MY_LIST,
    SCOPE_USER_MY_CREATE,
    SCOPE_USER_MY_UPDATE,
    SCOPE_USER_MY_DELETE,
    SCOPE_ROLE_MY_LIST,
    SCOPE_CANDIDATE_MY_LIST,
    SCOPE_CANDIDATE_MY_CREATE,
    SCOPE_CANDIDATE_MY_UPDATE,
    SCOPE_CANDIDATE_MY_DELETE,
    SCOPE_PIPELINE_MY_LIST,
    SCOPE_PIPELINE_MY_CREATE,
    SCOPE_PIPELINE_MY_UPDATE,
    SCOPE_PIPELINE_MY_DELETE,
    SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN,
    SCOPE_USER_MYSELF_GET,
    SCOPE_USER_MYSELF_UPDATE
]

DEFAULT_USER_SCOPES = [
    SCOPE_COMPANY_MYSELF_GET,
    SCOPE_CANDIDATE_MY_LIST,
    SCOPE_CANDIDATE_MY_CREATE,
    SCOPE_CANDIDATE_MY_UPDATE,
    SCOPE_ROLE_MYSELF_GET,
    SCOPE_PIPELINE_MY_LIST,
    SCOPE_PIPELINE_CANDIDATE_MY_ASSIGN,
    SCOPE_PIPELINE_CANDIDATE_MY_UNASSIGN,
    SCOPE_USER_MYSELF_GET,
    SCOPE_USER_MYSELF_UPDATE

]

DEFAULT_CANDIDATE_SCOPES = [
    SCOPE_CANDIDATE_MYSELF_GET,
    SCOPE_CANDIDATE_MYSELF_UPDATE,
    SCOPE_PIPELINE_MYSELF_GET
]

# Scopes that are always assigned to all the roles
DEFAULT_SCOPES = [
    SCOPE_COMPANY_MYSELF_GET,
    SCOPE_USER_MYSELF_GET,
    SCOPE_USER_MYSELF_UPDATE,
    SCOPE_ROLE_MYSELF_GET
]
